@@ -1,7 +1,7 @@
 ##
-## File: test_01.R
+## File:   test_01.R
 ## Author: Michael J. North
-## Date: September 14, 2015
+## Date:   November 25, 2015
 ##
 
 ## Note the type of test.
@@ -11,6 +11,5 @@ context("Directory trees")
 path <- system.file("extdata", ".", package = "SchemaOnRead")
 
 ## Perform an overall test.
-testthat::expect_that(
-        length(SchemaOnRead::schemaOnRead(path)),
-        testthat::equals(9))
+testthat::expect_that(length(SchemaOnRead::schemaOnRead(path)),
+  testthat::equals(9))
