@@ -1,7 +1,7 @@
 ##
 ## File: test_13.R
 ## Author: Michael J. North
-## Date: September 14, 2015
+## Date:   November 25, 2015
 ##
 
 ## Note the type of test.
@@ -9,9 +9,8 @@ context("ODS files")
 
 ## Note the data path.
 path <- system.file("extdata", paste("dir1", .Platform$file.sep,
-        "spreadsheet.ods", sep = ""), package = "SchemaOnRead")
+  "spreadsheet.ods", sep = ""), package = "SchemaOnRead")
 
 ## Perform a test.
-testthat::expect_that(
-        length(SchemaOnRead::schemaOnRead(path)),
-        testthat::equals(2))
+testthat::expect_that(length(SchemaOnRead::schemaOnRead(path)),
+  testthat::equals(2))
